@@ -42,6 +42,26 @@ class UrlTest(unittest.TestCase):
                 musicbrainzngs.get_artist_by_id,
                 artistid, ["release-groups"], release_status=["official"])
 
+    def testGetEvent(self):
+        event_id = "a4a0927c-8ad7-48dd-883c-7126cc0b9c6b"
+        musicbrainzngs.get_event_by_id(event_id)
+        self.assertEqual("http://musicbrainz.org/ws/2/event/a4a0927c-8ad7-48dd-883c-7126cc0b9c6b", self.opener.get_url())
+
+        # one include
+        musicbrainzngs.get_event_by_id(event_id, ["artist-rels"])
+        self.assertEqual("http://musicbrainz.org/ws/2/event/a4a0927c-8ad7-48dd-883c-7126cc0b9c6b?inc=artist-rels", self.opener.get_url())
+
+        musicbrainzngs.get_event_by_id(event_id, ["artist-rels", "event-rels", "ratings", "tags"])
+        self.assertEqual("http://musicbrainz.org/ws/2/event/a4a0927c-8ad7-48dd-883c-7126cc0b9c6b?inc=artist-rels+event-rels+ratings+tags", self.opener.get_url())
+
+    def testGetPlace(self):
+        place_id = "43e166a5-a024-4cbb-9a1f-d4947b4ff489"
+        musicbrainzngs.get_place_by_id(place_id)
+        self.assertEqual("http://musicbrainz.org/ws/2/place/43e166a5-a024-4cbb-9a1f-d4947b4ff489", self.opener.get_url())
+
+        musicbrainzngs.get_place_by_id(place_id, ["event-rels"])
+        self.assertEqual("http://musicbrainz.org/ws/2/place/43e166a5-a024-4cbb-9a1f-d4947b4ff489?inc=event-rels", self.opener.get_url())
+
     def testGetLabel(self):
         label_id = "aab2e720-bdd2-4565-afc2-460743585f16"
         musicbrainzngs.get_label_by_id(label_id)
@@ -106,3 +126,25 @@ class UrlTest(unittest.TestCase):
         self.assertEqual("http://musicbrainz.org/ws/2/discid/discid?cdstubs=no&toc=toc", self.opener.get_url())
 
 
+    def testGetInstrument(self):
+
+        musicbrainzngs.get_instrument_by_id("6505f98c-f698-4406-8bf4-8ca43d05c36f")
+        self.assertEqual("http://musicbrainz.org/ws/2/instrument/6505f98c-f698-4406-8bf4-8ca43d05c36f", self.opener.get_url())
+
+        # Tags
+        musicbrainzngs.get_instrument_by_id("6505f98c-f698-4406-8bf4-8ca43d05c36f", includes="tags")
+        self.assertEqual("http://musicbrainz.org/ws/2/instrument/6505f98c-f698-4406-8bf4-8ca43d05c36f?inc=tags", self.opener.get_url())
+
+        # some rels
+        musicbrainzngs.get_instrument_by_id("6505f98c-f698-4406-8bf4-8ca43d05c36f", includes=["instrument-rels", "url-rels"])
+        self.assertEqual("http://musicbrainz.org/ws/2/instrument/6505f98c-f698-4406-8bf4-8ca43d05c36f?inc=instrument-rels+url-rels", self.opener.get_url())
+
+        # alias, annotation
+        musicbrainzngs.get_instrument_by_id("d00cec5f-f9bc-4235-a54f-6639a02d4e4c", includes=["aliases", "annotation"])
+        self.assertEqual("http://musicbrainz.org/ws/2/instrument/d00cec5f-f9bc-4235-a54f-6639a02d4e4c?inc=aliases+annotation", self.opener.get_url())
+
+        # Ratings are used on almost all other entites but instrument
+        self.assertRaises(musicbrainzngs.UsageError,
+                musicbrainzngs.get_instrument_by_id,
+                "dabdeb41-560f-4d84-aa6a-cf22349326fe", includes=["ratings"])
+
