@@ -6,7 +6,7 @@ import sys
 # Insert .. at the beginning of path so we use this version instead
 # of something that's already been installed
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-from musicbrainzngs import mbxml
+from test import _common
 
 
 class GetReleaseGroupTest(unittest.TestCase):
@@ -15,17 +15,17 @@ class GetReleaseGroupTest(unittest.TestCase):
                 "release-group")
 
     def testTypesExist(self):
-        fn = os.path.join(self.datadir,
+        res = _common.open_and_parse_test_data(self.datadir,
                           "f52bc6a1-c848-49e6-85de-f8f53459a624.xml")
-        res = mbxml.parse_message(open(fn))["release-group"]
-        self.assertTrue("type" in res)
-        self.assertTrue("primary-type" in res)
-        self.assertTrue("secondary-type-list" in res)
+        rg = res["release-group"]
+        self.assertTrue("type" in rg)
+        self.assertTrue("primary-type" in rg)
+        self.assertTrue("secondary-type-list" in rg)
 
     def testTypesResult(self):
-        fn = os.path.join(self.datadir,
+        res = _common.open_and_parse_test_data(self.datadir,
                           "f52bc6a1-c848-49e6-85de-f8f53459a624.xml")
-        res = mbxml.parse_message(open(fn))["release-group"]
-        self.assertEqual("Soundtrack", res["type"])
-        self.assertEqual("Album", res["primary-type"])
-        self.assertEqual(["Soundtrack"], res["secondary-type-list"])
+        rg = res["release-group"]
+        self.assertEqual("Soundtrack", rg["type"])
+        self.assertEqual("Album", rg["primary-type"])
+        self.assertEqual(["Soundtrack"], rg["secondary-type-list"])
